@@ -24,13 +24,11 @@
  */
 package org.slf4j.dummyExt;
 
-import junit.framework.*;
-
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 import org.junit.runners.Suite.SuiteClasses;
 
 @RunWith(Suite.class)
-@SuiteClasses({ MDCStrLookupTest.class, XLoggerTest.class, EventLoggerTest.class })
+@SuiteClasses({ MDCStrLookupTest.class, XLoggerTest.class })
 public class PackageTest {
 }
