@@ -157,7 +157,7 @@ public class SimpleLogger extends MarkerIgnoringBase {
     protected static final int LOG_LEVEL_OFF = LOG_LEVEL_ERROR + 10;
 
     private static boolean INITIALIZED = false;
-    static SimpleLoggerConfiguration CONFIG_PARAMS = null;
+    static final private SimpleLoggerConfiguration CONFIG_PARAMS =  new SimpleLoggerConfiguration();
 
     static void lazyInit() {
         if (INITIALIZED) {
@@ -170,7 +170,6 @@ public class SimpleLogger extends MarkerIgnoringBase {
     // external software might be invoking this method directly. Do not rename
     // or change its semantics.
     static void init() {
-        CONFIG_PARAMS = new SimpleLoggerConfiguration();
         CONFIG_PARAMS.init();
     }
 
@@ -312,12 +311,22 @@ public class SimpleLogger extends MarkerIgnoringBase {
         throw new IllegalStateException("Unrecognized level [" + level + "]");
     }
 
+    /**
+     * To avoid intermingling of log messages and associated stack traces, the two
+     * operations are done in a synchronized block.
+     * 
+     * @param buf
+     * @param t
+     */
     void write(StringBuilder buf, Throwable t) {
         PrintStream targetStream = CONFIG_PARAMS.outputChoice.getTargetPrintStream();
 
-        targetStream.println(buf.toString());
-        writeThrowable(t, targetStream);
-        targetStream.flush();
+        synchronized (CONFIG_PARAMS) {
+            targetStream.println(buf.toString());
+            writeThrowable(t, targetStream);
+            targetStream.flush();
+        }
+
     }
 
     protected void writeThrowable(Throwable t, PrintStream targetStream) {
